<?php

class SupportHeroWP_Admin {
    public function init() {
        add_action('admin_menu', [$this, 'add_plugin_menu']);
        add_action('admin_enqueue_scripts', [$this, 'enqueue_admin_assets']);
        add_action('password_reset', [$this, 'record_password_change'], 10, 2);
        add_action('profile_update', [$this, 'record_password_change'], 10, 2);
        
        // New AJAX actions for settings
        add_action('wp_ajax_supportherowp_get_settings', [$this, 'handle_get_settings']);
        add_action('wp_ajax_supportherowp_update_settings', [$this, 'handle_update_settings']);
    }

    public function record_password_change($user, $new_pass = null) {
        if ($new_pass) {
            update_user_meta($user->ID, 'last_password_change', current_time('mysql'));
        }
    }

    public function add_plugin_menu() {
        add_menu_page(
            __('SupportHeroWP', 'supportherowp'),
            __('SupportHeroWP', 'supportherowp'),
            'manage_options',
            'supportherowp',
            [$this, 'render_dashboard'],
            'dashicons-shield-alt',
            6
        );
    }

    public function render_dashboard() {
        echo '<div id="supportherowp-dashboard"></div>';
    }

    public function render_settings_page() {
        echo '<div id="supportherowp-dashboard"></div>';
    }

    public function enqueue_admin_assets($hook) {
        // Enqueue scripts only on main plugin page and settings page
        if (!in_array($hook, ['toplevel_page_supportherowp', 'supportherowp-settings'])) {
            return;
        }

        // Enqueue React app
        wp_enqueue_script(
            'supportherowp-react',
            SUPPORTHEROWP_PLUGIN_URL . 'assets/js/main.js',
            ['wp-element', 'wp-api'],
            SUPPORTHEROWP_VERSION,
            true
        );

        // Enqueue Tailwind CSS
        wp_enqueue_style(
            'supportherowp-tailwind',
            SUPPORTHEROWP_PLUGIN_URL . 'assets/css/main.css',
            [],
            SUPPORTHEROWP_VERSION
        );          

        // Current user logic
        $current_user = wp_get_current_user();
        $display_name = $current_user->display_name ? $current_user->display_name : 'User';

        // Determine the default page based on the admin page
        $defaultPage = 'dashboard';
        if ($hook === 'supportherowp-settings') {
            $defaultPage = 'settings';
        }

        // Localize script without exposing the API key
        wp_localize_script('supportherowp-react', 'supportherowp', [
            'ajaxurl'      => admin_url('admin-ajax.php'),
            'nonce'        => wp_create_nonce('supportherowp_nonce'),
            'chat_nonce'   => wp_create_nonce('supportherowp_chat_nonce'),
            'currentUser'  => $display_name,
            'pluginUrl'    => SUPPORTHEROWP_PLUGIN_URL,
            'defaultPage'  => $defaultPage, // Pass the default page
        ]);
    }

    public function handle_get_settings() {
        check_ajax_referer('supportherowp_nonce', 'nonce');

        if (!current_user_can('manage_options')) {
            wp_send_json_error('Unauthorized', 403);
        }

        $openai_key = get_option('supportherowp_openai_key', '');
        $experts_email = get_option('supportherowp_experts_email', '');

        wp_send_json_success([
            'openai_key' => $openai_key,
            'experts_email' => $experts_email,
        ]);
    }

    public function handle_update_settings() {
        check_ajax_referer('supportherowp_nonce', 'nonce');

        if (!current_user_can('manage_options')) {
            wp_send_json_error('Unauthorized', 403);
        }

        $openai_key = isset($_POST['openai_key']) ? sanitize_text_field(wp_unslash($_POST['openai_key'])) : '';
        $experts_email = isset($_POST['experts_email']) ? sanitize_email(wp_unslash($_POST['experts_email'])) : '';

        // Validate inputs
        if (empty($openai_key)) {
            wp_send_json_error('OpenAI API key is required.', 400);
        }

        if (!is_email($experts_email)) {
            wp_send_json_error('A valid Experts Email is required.', 400);
        }

        // Update options
        update_option('supportherowp_openai_key', $openai_key);
        update_option('supportherowp_experts_email', $experts_email);

        wp_send_json_success('Settings updated successfully.');
    }
}
