<?php
use GuzzleHttp\Client;

class Diagnostic_Scanner {
    protected $ai_service;
    protected $table_name;
    protected $plugin_dir; // Added property to store plugin directory

    public function __construct() {
        global $wpdb;
        $this->ai_service = new AI_Service();
        $this->table_name = $wpdb->prefix . 'supportherowp_scans';
        $this->plugin_dir = SUPPORTHEROWP_PLUGIN_DIR; // Initialize plugin directory
    
        if (!$this->ai_service->is_ready()) {
            error_log('SupportHeroWP: AI Service is not ready. Configure the OpenAI API key in settings.');
        }
    }
    
    private function scan_site() {
        if (!$this->ai_service->is_ready()) {
            return [
                'error' => 'AI Service is not ready. Set the API key in plugin settings.',
            ];
        }
    
        $r = [];
        $r['plugins'] = $this->analyze_plugins();
        $r['themes'] = $this->analyze_themes();
        $r['database'] = $this->analyze_database();
        $r['files'] = $this->analyze_files();
        $r['performance'] = $this->analyze_performance();
        $r['security'] = $this->analyze_security();
        $encoded = json_encode($r);
        $analysis = $this->ai_service->analyze($encoded);
        $rec_sec = $this->generate_security_recommendations($r);
        $rec_perf = $this->generate_performance_recommendations($r);
        return [
            'scan_results' => $r,
            'ai_analysis' => $analysis,
            'recommendations' => [
                'security' => $rec_sec,
                'performance' => $rec_perf,
            ],
        ];
    }
    

    public static function activate_plugin() {
        global $wpdb;
        $table_name = $wpdb->prefix . 'supportherowp_scans';
        $charset_collate = $wpdb->get_charset_collate();
        $sql = "CREATE TABLE IF NOT EXISTS $table_name (
            id BIGINT(20) UNSIGNED NOT NULL AUTO_INCREMENT,
            user_id BIGINT(20) UNSIGNED NOT NULL,
            scan_data LONGTEXT NOT NULL,
            created_at DATETIME NOT NULL,
            PRIMARY KEY (id)
        ) $charset_collate;";
        require_once(ABSPATH . 'wp-admin/includes/upgrade.php');
        dbDelta($sql);
    }

    public static function activate() {
        self::activate_plugin();
    }

    public function init() {
        add_action('wp_ajax_supportherowp_scan', [$this, 'handle_scan']);
        add_action('wp_ajax_supportherowp_chat', [$this, 'handle_chat']);
        // Additional AJAX actions
        add_action('wp_ajax_supportherowp_get_scan_histories', [$this, 'handle_get_scan_histories']);
        add_action('wp_ajax_supportherowp_delete_scan_history', [$this, 'handle_delete_scan_history']);
        // Register the new AJAX action for updating plugins (if implemented in future)
    }

    public function handle_scan() {
        if (!isset($_POST['nonce']) || !check_ajax_referer('supportherowp_nonce', 'nonce', false)) {
            wp_send_json_error('Invalid nonce.', 400);
        }
        if (!current_user_can('manage_options')) {
            wp_send_json_error('Unauthorized', 403);
        }
        try {
            $scan = $this->scan_site();
            $this->save_scan_data($scan);
            wp_send_json_success($scan);
        } catch (Exception $e) {
            wp_send_json_error('Scan failed: ' . $e->getMessage(), 500);
        }
    }

    public function handle_chat() {
        if (!isset($_POST['nonce']) || !check_ajax_referer('supportherowp_chat_nonce', 'nonce', false)) {
            wp_send_json_error('Invalid nonce.', 400);
        }
        if (!current_user_can('manage_options')) {
            wp_send_json_error('Unauthorized', 403);
        }
        $message = isset($_POST['message']) ? sanitize_text_field(wp_unslash($_POST['message'])) : '';
        if (empty($message)) {
            wp_send_json_error('Empty message.', 400);
        }
        // if (!$this->check_rate_limit(get_current_user_id())) {
        //     wp_send_json_error('Rate limit exceeded. Please try again later.', 429);
        // }
        $scan_data = $this->get_latest_scan_data(get_current_user_id());
        $prompt = $this->build_context_prompt($scan_data, $message);
        $reply = $this->send_to_openai($prompt);
        if (empty($reply)) {
            wp_send_json_error('AI did not return a response.', 500);
        }
        wp_send_json_success(['reply' => $reply]);
    }

    private function save_scan_data($scan) {
        global $wpdb;
        $user_id = get_current_user_id();
        $serialized = maybe_serialize($scan);
        $ok = $wpdb->insert($this->table_name, [
            'user_id' => $user_id,
            'scan_data' => $serialized,
            'created_at' => current_time('mysql')
        ]);
        if ($ok === false) {
            error_log('SupportHeroWP: Insert into table failed. ' . $wpdb->last_error);
        }
    }

    private function get_latest_scan_data($user_id) {
        global $wpdb;
        $sql = $wpdb->prepare("SELECT scan_data FROM {$this->table_name} WHERE user_id=%d ORDER BY id DESC LIMIT 1", $user_id);
        $row = $wpdb->get_row($sql);
        if (!$row) {
            error_log('SupportHeroWP: No scan data found for user_id ' . $user_id);
            return [];
        }
        $data = maybe_unserialize($row->scan_data);
        if (empty($data)) {
            error_log('SupportHeroWP: Could not unserialize scan data or it was empty.');
            return [];
        }
        return $data;
    }

    private function build_context_prompt($scan_data, $userMessage) {
        $prompt = "You are SupportHeroWP, a helpful assistant for WordPress site issues.\n\n";
        if (!empty($scan_data['scan_results'])) {
            $sr = $scan_data['scan_results'];
            if (!empty($sr['plugins']['inactive_plugins'])) {
                $prompt .= "Inactive Plugins:\n";
                foreach ($sr['plugins']['inactive_plugins'] as $ip) {
                    $prompt .= "- {$ip['name']} (Version: {$ip['version']})\n";
                }
                $prompt .= "\n";
            }
            if (!empty($sr['plugins']['vulnerable_plugins'])) {
                $prompt .= "Vulnerable Plugins:\n";
                foreach ($sr['plugins']['vulnerable_plugins'] as $vp) {
                    $prompt .= "- {$vp['name']} (Version: {$vp['version']})\n";
                }
                $prompt .= "\n";
            }
            if (!empty($sr['security']['security_issues'])) {
                $prompt .= "Security Issues:\n";
                foreach ($sr['security']['security_issues'] as $issue) {
                    $prompt .= "- {$issue['issue']}\n";
                }
                $prompt .= "\n";
            }
        }
        if (!empty($scan_data['ai_analysis'])) {
            $prompt .= "AI Analysis:\n{$scan_data['ai_analysis']}\n\n";
        }
        if (!empty($scan_data['recommendations'])) {
            $r = $scan_data['recommendations'];
            if (!empty($r['security'])) {
                $prompt .= "Security Recommendations:\n{$r['security']}\n\n";
            }
            if (!empty($r['performance'])) {
                $prompt .= "Performance Recommendations:\n{$r['performance']}\n\n";
            }
        }
        $prompt .= "User question:\n{$userMessage}\n\nPlease answer with reference to the data above if relevant.";
        return $prompt;
    }

    private function send_to_openai($prompt) {
        $api_key = get_option('supportherowp_openai_key', '');
        if (empty($api_key)) {
            return 'OpenAI API key not configured.';
        }
        $api_url = 'https://api.openai.com/v1/chat/completions';
        $headers = [
            'Content-Type' => 'application/json',
            'Authorization' => 'Bearer ' . $api_key,
        ];
        $body = json_encode([
            'model' => 'gpt-4o-mini',
            'messages' => [
                ['role' => 'system', 'content' => 'You are a helpful assistant for WordPress site issues.'],
                ['role' => 'user', 'content' => $prompt],
            ],
            'max_tokens' => 500,
            'temperature' => 0.7,
        ]);
        $response = wp_remote_post($api_url, [
            'headers' => $headers,
            'body' => $body,
            'timeout' => 60,
        ]);
        if (is_wp_error($response)) {
            return 'OpenAI API request failed: ' . $response->get_error_message();
        }
        $code = wp_remote_retrieve_response_code($response);
        $content = wp_remote_retrieve_body($response);
        if ($code !== 200) {
            return 'OpenAI API error: ' . $content;
        }
        $data = json_decode($content, true);
        if (!isset($data['choices'][0]['message']['content'])) {
            return 'Invalid response from OpenAI API.';
        }
        return trim($data['choices'][0]['message']['content']);
    }

    private function check_rate_limit($user_id) {
        $rate_limit_key = 'supportherowp_chat_count';
        $rate_limit = 10;
        $window = HOUR_IN_SECONDS;
        $now = time();
        $chat_data = get_user_meta($user_id, $rate_limit_key, true);
        if (!is_array($chat_data)) {
            $chat_data = ['count' => 0, 'start_time' => date('Y-m-d H:i:s', $now)];
        }
        if (strtotime($chat_data['start_time']) + $window < $now) {
            $chat_data = ['count' => 0, 'start_time' => date('Y-m-d H:i:s', $now)];
        }
        if ($chat_data['count'] >= $rate_limit) {
            return false;
        }
        $chat_data['count'] += 1;
        update_user_meta($user_id, $rate_limit_key, $chat_data);
        return true;
    }

    private function analyze_plugins() {
        $plugins = get_plugins();
        $outdated_plugins = [];
        $vulnerable_plugins = [];
        $inactive_plugins = [];
        $plugin_updates = get_site_transient('update_plugins');
        if (isset($plugin_updates->response) && is_array($plugin_updates->response)) {
            $plugin_updates = $plugin_updates->response;
        } else {
            $plugin_updates = [];
        }

        // Determine the main plugin file of SupportHeroWP
        $supportherowp_main_file = 'supportherowp/supportherowp.php'; // Adjust if different

        foreach ($plugins as $plugin_path => $plugin_info) {
            // **Exclude SupportHeroWP Plugin**
            if ($plugin_path === $supportherowp_main_file) {
                continue; // Skip analyzing this plugin
            }

            if (strpos($plugin_path, 'mu-plugins/') === 0) {
                continue;
            }
            $slug = dirname($plugin_path);
            $ver = $plugin_info['Version'];
            $active = is_plugin_active($plugin_path);
            if (isset($plugin_updates[$plugin_path])) {
                $latest = $plugin_updates[$plugin_path]->new_version;
                if (version_compare($ver, $latest, '<')) {
                    $outdated_plugins[] = [
                        'name' => $plugin_info['Name'],
                        'current_version' => $ver,
                        'latest_version' => $latest,
                        'update_url' => $plugin_updates[$plugin_path]->url,
                        'is_active' => $active,
                        'plugin_folder' => $slug,
                    ];
                }
            }
            if (!$active) {
                $inactive_plugins[] = [
                    'name' => $plugin_info['Name'],
                    'version' => $ver,
                    'plugin_folder' => $slug,
                ];
            }
            if ($active) {
                $insecure = [
                    '/eval\((.*?)\)/i',
                    '/base64_decode\((.*?)\)/i',
                    '/gzinflate\((.*?)\)/i',
                    '/preg_replace\((.*?)\)/i',
                    '/system\((.*?)\)/i',
                    '/shell_exec\((.*?)\)/i',
                ];
                $dir = WP_PLUGIN_DIR . '/' . $slug;
                $sus = $this->scan_directory_for_patterns($dir, $insecure);
                if (!empty($sus)) {
                    $vulnerable_plugins[] = [
                        'name' => $plugin_info['Name'],
                        'version' => $ver,
                        'suspicious_files' => $sus,
                        'plugin_folder' => $slug,
                    ];
                }
            }
        }
        return [
            'outdated_plugins' => $outdated_plugins,
            'inactive_plugins' => $inactive_plugins,
            'vulnerable_plugins' => $vulnerable_plugins,
        ];
    }

    private function analyze_themes() {
        $themes = wp_get_themes();
        $outdated_themes = [];
        $vulnerable_themes = [];
        $inactive_themes = [];
        $theme_updates = get_site_transient('update_themes');
        if (isset($theme_updates->response) && is_array($theme_updates->response)) {
            $theme_updates = $theme_updates->response;
        } else {
            $theme_updates = [];
        }
        foreach ($themes as $slug => $theme) {
            $ver = $theme->get('Version');
            $active_theme = wp_get_theme();
            $active_slug = $active_theme->get_stylesheet();
            $is_active = ($slug === $active_slug);
            if (isset($theme_updates[$slug])) {
                $latest_version = $theme_updates[$slug]->new_version;
                if (version_compare($ver, $latest_version, '<')) {
                    $outdated_themes[] = [
                        'name' => $theme->get('Name'),
                        'current_version' => $ver,
                        'latest_version' => $latest_version,
                        'update_url' => $theme_updates[$slug]->url,
                        'is_active' => $is_active,
                        'theme_folder' => $slug,
                    ];
                }
            }
            if (!$is_active) {
                $inactive_themes[] = [
                    'name' => $theme->get('Name'),
                    'version' => $ver,
                    'theme_folder' => $slug,
                ];
            }
            if ($is_active) {
                $insecure = [
                    '/eval\((.*?)\)/i',
                    '/base64_decode\((.*?)\)/i',
                    '/gzinflate\((.*?)\)/i',
                    '/preg_replace\((.*?)\)/i',
                    '/system\((.*?)\)/i',
                    '/shell_exec\((.*?)\)/i',
                ];
                $dir = get_theme_root() . '/' . $slug;
                $sus = $this->scan_directory_for_patterns($dir, $insecure);
                if (!empty($sus)) {
                    $vulnerable_themes[] = [
                        'name' => $theme->get('Name'),
                        'version' => $ver,
                        'suspicious_files' => $sus,
                        'theme_folder' => $slug,
                    ];
                }
            }
        }
        return [
            'outdated_themes' => $outdated_themes,
            'inactive_themes' => $inactive_themes,
            'vulnerable_themes' => $vulnerable_themes,
        ];
    }

    private function analyze_database() {
        global $wpdb;
        $unoptimized_tables = [];
        $tables = $wpdb->get_results("SHOW TABLE STATUS", ARRAY_A);
        foreach ($tables as $table) {
            if ($table['Data_free'] > 0) {
                $unoptimized_tables[] = [
                    'name' => $table['Name'],
                    'overhead' => $table['Data_free'],
                ];
            }
        }
        return [
            'unoptimized_tables' => $unoptimized_tables,
        ];
    }

    private function analyze_files() {
        $suspicious_files = [];
        $modified_core_files = [];
        $wp_content_dir = WP_CONTENT_DIR;
        $directories = [
            $wp_content_dir . '/plugins',
            $wp_content_dir . '/themes',
            $wp_content_dir . '/uploads',
        ];
        $insecure_patterns = [
            '/eval\((.*?)\)/i',
            '/base64_decode\((.*?)\)/i',
            '/gzinflate\((.*?)\)/i',
            '/preg_replace\((.*?)\)/i',
            '/system\((.*?)\)/i',
            '/shell_exec\((.*?)\)/i',
            '/\.(php|phtml|php3|php4|php5|php7)$/i',
        ];
        $forbidden_uploads = [
            '/\.php$/i',
            '/\.phtml$/i',
            '/\.php3$/i',
            '/\.php4$/i',
            '/\.php5$/i',
            '/\.php7$/i',
        ];
        foreach ($directories as $dir) {
            if (!is_dir($dir)) continue;
            $files = new RecursiveIteratorIterator(new RecursiveDirectoryIterator($dir));
            foreach ($files as $file) {
                if ($file->isDir()) continue;
                $path = $file->getRealPath();
    
                // **Exclude SupportHeroWP Plugin Files**
                if (strpos($path, $this->plugin_dir) === 0) {
                    continue; // Skip files within the SupportHeroWP plugin directory
                }
    
                if ($file->getSize() > 1048576) continue;
                if (strpos($dir, '/uploads') !== false) {
                    foreach ($forbidden_uploads as $pat) {
                        if (preg_match($pat, $path)) {
                            $suspicious_files[] = [
                                'file' => $path,
                                'reason' => 'Forbidden file type in uploads directory',
                            ];
                            break;
                        }
                    }
                    continue;
                }
                $contents = file_get_contents($path);
                foreach ($insecure_patterns as $pattern) {
                    if (preg_match($pattern, $contents)) {
                        $suspicious_files[] = [
                            'file' => $path,
                            'pattern_matched' => $pattern,
                        ];
                        break;
                    }
                }
            }
        }
        $modified_core_files = $this->check_modified_core_files();
        return [
            'suspicious_files' => $suspicious_files,
            'modified_core_files' => $modified_core_files,
        ];
    }
    

    private function analyze_performance() {
        global $wpdb;
        $transients = $wpdb->get_var("SELECT COUNT(*) FROM $wpdb->options WHERE option_name LIKE '_transient_%'");
        $issues = [];
        if ($transients > 1000) {
            $issues[] = [
                'issue' => 'High number of transients',
                'recommendation' => 'Consider cleaning up unused transients.',
            ];
        }
        return [
            'performance_issues' => $issues,
        ];
    }

    private function analyze_security() {
        $security_issues = [];
        $admins = get_users(['role' => 'Administrator']);
        foreach ($admins as $u) {
            if ($u->user_login === 'admin') {
                $security_issues[] = [
                    'issue' => 'Default Administrator Username',
                    'recommendation' => 'Change the default "admin" username.',
                ];
            }
        }
        $insecure = $this->check_file_permissions();
        if (!empty($insecure)) {
            $security_issues[] = [
                'issue' => 'Insecure File Permissions',
                'details' => $insecure,
                'recommendation' => 'Ensure critical files have secure perms.',
            ];
        }
        $wp_debug = defined('WP_DEBUG') && WP_DEBUG;
        if ($wp_debug) {
            $security_issues[] = [
                'issue' => 'WP_DEBUG is Enabled',
                'recommendation' => 'Disable WP_DEBUG in wp-config.php.',
            ];
        }
        $weak_pass = $this->detect_weak_passwords();
        if (!empty($weak_pass)) {
            $security_issues[] = [
                'issue' => 'Weak Passwords Detected',
                'details' => $weak_pass,
                'recommendation' => 'Encourage stronger passwords.',
            ];
        }
        return [
            'security_issues' => $security_issues,
        ];
    }

    private function detect_weak_passwords() {
        $weak = [];
        $users = get_users(['fields' => ['ID', 'user_login', 'user_email']]);
        foreach ($users as $u) {
            $last_change = get_user_meta($u->ID, 'last_password_change', true);
            if (!$last_change || (time() - strtotime($last_change)) > YEAR_IN_SECONDS) {
                $weak[] = [
                    'username' => $u->user_login,
                    'email' => $u->user_email,
                    'last_change' => $last_change ? date('Y-m-d', strtotime($last_change)) : 'Never',
                ];
            }
        }
        return $weak;
    }

    private function check_file_permissions() {
        $bad = [];
        $critical = [
            ABSPATH . 'wp-config.php',
            ABSPATH . '.htaccess',
            ABSPATH . 'wp-admin/',
            ABSPATH . 'wp-includes/',
        ];
        foreach ($critical as $path) {
            if (file_exists($path)) {
                $perms = fileperms($path);
                if (($perms & 0x0002) || ($perms & 0x0010) || ($perms & 0x0001)) {
                    $bad[] = [
                        'path' => $path,
                        'permissions' => substr(sprintf('%o', $perms), -4),
                    ];
                }
            }
        }
        return $bad;
    }

    private function scan_directory_for_patterns($directory, $patterns) {
        $matched = [];
        if (!is_dir($directory)) return $matched;
        $files = new RecursiveIteratorIterator(new RecursiveDirectoryIterator($directory));
        foreach ($files as $file) {
            if ($file->isDir()) continue;

            // **Exclude SupportHeroWP Plugin Files**
            $path = $file->getRealPath();
            if (strpos($path, $this->plugin_dir) === 0) {
                continue; // Skip files within the SupportHeroWP plugin directory
            }

            if ($file->getSize() > 1048576) continue;
            $path = $file->getRealPath();
            $contents = file_get_contents($path);
            foreach ($patterns as $pat) {
                if (preg_match($pat, $contents)) {
                    $matched[] = [
                        'file' => $path,
                        'pattern_matched' => $pat,
                    ];
                    break;
                }
            }
        }
        return $matched;
    }

    private function generate_security_recommendations($scan_results) {
        $p = "Based on the following WordPress scan results, provide detailed security recommendations:\n\n"
            . json_encode($scan_results);
        return $this->ai_service->analyze($p);
    }

    private function generate_performance_recommendations($scan_results) {
        $p = "Based on the following WordPress scan results, provide detailed performance recommendations:\n\n"
            . json_encode($scan_results);
        return $this->ai_service->analyze($p);
    }

    private function check_modified_core_files() {
        $modified = [];
        $core_dir = ABSPATH;
        $core_files = ['wp-config.php', '.htaccess'];
        foreach ($core_files as $file) {
            $file_path = $core_dir . $file;
            if (file_exists($file_path)) {
                $v = get_bloginfo('version');
                $official_url = "https://raw.githubusercontent.com/WordPress/WordPress/$v/$file";
                $resp = wp_remote_get($official_url);
                if (is_wp_error($resp)) {
                    continue;
                }
                $official = wp_remote_retrieve_body($resp);
                $current = file_get_contents($file_path);
                if ($official !== $current) {
                    $modified[] = [
                        'file' => $file_path,
                        'description' => 'Core file has been modified.',
                    ];
                }
            }
        }
        return $modified;
    }

    // For Analysis Page
    public function handle_get_scan_histories() {
        check_ajax_referer('supportherowp_nonce', 'nonce');
        if (!current_user_can('manage_options')) {
            wp_send_json_error('Unauthorized', 403);
        }
    
        global $wpdb;
        $table_name = $wpdb->prefix . 'supportherowp_scans';
        $results = $wpdb->get_results("SELECT * FROM $table_name ORDER BY id DESC", ARRAY_A);
        if (!$results) {
            wp_send_json_success([]); 
        }
    
        // Convert each row's 'scan_data' from PHP-serialized to JSON
        foreach ($results as &$row) {
            // Unserialize the data
            $scan_array = maybe_unserialize($row['scan_data']); // now it's an array
            
            // If unserialize fails => $scan_array could be false
            if (!is_array($scan_array)) {
                // handle error or skip
                $row['scan_data_json'] = null;
                continue;
            }
    
            // Convert that array to JSON so the frontend can do JSON.parse safely if needed
            $row['scan_data_json'] = wp_json_encode($scan_array);
        }
    
        // Now each row has 'scan_data_json' containing real JSON
        wp_send_json_success($results);
    }
    
    
    public function handle_delete_scan_history() {
        check_ajax_referer('supportherowp_nonce', 'nonce');
        if (!current_user_can('manage_options')) {
            wp_send_json_error('Unauthorized', 403);
        }
        $history_id = isset($_POST['history_id']) ? absint($_POST['history_id']) : 0;
        if (!$history_id) {
            wp_send_json_error('Invalid History ID', 400);
        }
        global $wpdb;
        $table_name = $wpdb->prefix . 'supportherowp_scans';
        $deleted = $wpdb->delete($table_name, ['id' => $history_id]);
        if ($deleted === false) {
            wp_send_json_error('DB delete error', 500);
        }
        wp_send_json_success('History deleted successfully.');
    }
}
