// src/components/Header.jsx

import React, { useState, useEffect, useRef } from 'react';
import { FaBell } from 'react-icons/fa';
import menuItems from '../menuItems'; // Ensure menuItems.js is correctly defined and exported

const Header = ({ currentUser, onChangePage }) => {
  // State variables for search functionality
  const [searchInput, setSearchInput] = useState('');
  const [suggestions, setSuggestions] = useState([]);
  const [showSuggestions, setShowSuggestions] = useState(false);
  const [activeSuggestion, setActiveSuggestion] = useState(-1);

  // Refs for handling clicks outside the search area
  const inputRef = useRef(null);
  const suggestionsRef = useRef(null);

  // Format current date
  const dateStr = new Date().toLocaleDateString('en-GB', {
    weekday: 'short',
    day: '2-digit',
    month: 'long',
    year: 'numeric',
  });

  // Debounce timer reference
  const debounceTimeout = useRef(null);

  // Effect to handle search input changes with debounce
  useEffect(() => {
    // Clear the previous debounce timer
    if (debounceTimeout.current) {
      clearTimeout(debounceTimeout.current);
    }

    // Set a new debounce timer
    debounceTimeout.current = setTimeout(() => {
      if (searchInput.trim() === '') {
        setSuggestions([]);
        return;
      }

      const input = searchInput.toLowerCase();

      // Filter menu items based on input matching keywords or labels
      const filtered = menuItems.filter(
        (item) =>
          item.keywords.some((keyword) => keyword.includes(input)) ||
          item.label.toLowerCase().includes(input)
      );

      setSuggestions(filtered);
    }, 300); // 300ms debounce delay

    // Cleanup function to clear the debounce timer
    return () => {
      if (debounceTimeout.current) {
        clearTimeout(debounceTimeout.current);
      }
    };
  }, [searchInput]);

  // Handler for input changes
  const handleInputChange = (e) => {
    setSearchInput(e.target.value);
    setShowSuggestions(true);
    setActiveSuggestion(-1);
  };

  // Handler for clicking on a suggestion
  const handleSuggestionClick = (page) => {
    setSearchInput('');
    setSuggestions([]);
    setShowSuggestions(false);
    if (onChangePage && typeof onChangePage === 'function') {
      onChangePage(page);
    }
  };

  // Handler for keyboard navigation
  const handleKeyDown = (e) => {
    if (e.key === 'ArrowDown') {
      e.preventDefault();
      if (activeSuggestion < suggestions.length - 1) {
        setActiveSuggestion((prev) => prev + 1);
      }
    } else if (e.key === 'ArrowUp') {
      e.preventDefault();
      if (activeSuggestion > 0) {
        setActiveSuggestion((prev) => prev - 1);
      }
    } else if (e.key === 'Enter') {
      e.preventDefault();
      if (activeSuggestion >= 0 && activeSuggestion < suggestions.length) {
        handleSuggestionClick(suggestions[activeSuggestion].page);
      }
    } else if (e.key === 'Escape') {
      setShowSuggestions(false);
    }
  };

  // Handler to close suggestions when clicking outside
  const handleClickOutside = (e) => {
    if (
      suggestionsRef.current &&
      !suggestionsRef.current.contains(e.target) &&
      inputRef.current &&
      !inputRef.current.contains(e.target)
    ) {
      setShowSuggestions(false);
    }
  };

  // Effect to add event listener for clicks outside
  useEffect(() => {
    document.addEventListener('mousedown', handleClickOutside);
    return () => {
      document.removeEventListener('mousedown', handleClickOutside);
    };
  }, []);

  // Function to highlight matched text in suggestions
  const getHighlightedText = (text, highlight) => {
    if (!highlight) return text;
    const parts = text.split(new RegExp(`(${highlight})`, 'gi'));
    return (
      <span>
        {parts.map((part, i) =>
          part.toLowerCase() === highlight.toLowerCase() ? (
            <span key={i} className="font-semibold text-orange-500">
              {part}
            </span>
          ) : (
            part
          )
        )}
      </span>
    );
  };

  return (
    <header className="flex items-center justify-between px-6 py-4 bg-[#F9F9F9] relative">
      {/* Welcome Section */}
      <div>
        <h1 className="text-xl font-semibold text-gray-800">Welcome, {currentUser}</h1>
        <p className="text-sm text-gray-500 mt-1">{dateStr}</p>
      </div>

      {/* Search & Notification */}
      <div className="flex items-center gap-4">
        {/* Search Bar */}
        <div className="relative w-72" ref={suggestionsRef}>
          <input
            type="text"
            placeholder="Search..."
            value={searchInput}
            onChange={handleInputChange}
            onKeyDown={handleKeyDown}
            onFocus={() => setShowSuggestions(true)}
            ref={inputRef}
            className="w-full bg-white pr-10 pl-4 !py-1 !border-[#f9f9f9] rounded-lg shadow-sm focus:outline-none text-sm"
            aria-label="Search"
          />
          {/* Search Icon */}
          <svg
            xmlns="http://www.w3.org/2000/svg"
            className="absolute right-3 top-1/2 transform -translate-y-1/2 h-5 w-5 text-gray-400 pointer-events-none"
            viewBox="0 0 24 24"
            fill="none"
            stroke="currentColor"
            strokeWidth={2}
          >
            <path
              strokeLinecap="round"
              strokeLinejoin="round"
              d="M8 4a8 8 0 106 14.32l4.58 4.58a1 1 0 001.42-1.42l-4.58-4.58A8 8 0 008 4z"
            />
          </svg>

          {/* Suggestions Dropdown */}
          {showSuggestions && suggestions.length > 0 && (
            <div className="absolute top-full left-0 right-0 bg-white border border-gray-300 rounded-b-lg shadow-lg max-h-60 overflow-y-auto z-10 mt-1">
              <ul>
                {suggestions.map((item, index) => (
                  <li
                    key={item.page}
                    className={`px-4 py-2 cursor-pointer hover:bg-gray-100 ${
                      index === activeSuggestion ? 'bg-gray-100' : ''
                    }`}
                    onClick={() => handleSuggestionClick(item.page)}
                    onMouseEnter={() => setActiveSuggestion(index)}
                    onMouseLeave={() => setActiveSuggestion(-1)}
                    role="option"
                    aria-selected={index === activeSuggestion}
                  >
                    {getHighlightedText(item.label, searchInput)}
                  </li>
                ))}
              </ul>
            </div>
          )}

          {/* No Results Found */}
          {showSuggestions && searchInput.trim() !== '' && suggestions.length === 0 && (
            <div className="absolute top-full left-0 right-0 bg-white border border-gray-300 rounded-b-lg shadow-lg max-h-60 overflow-y-auto z-10 mt-1">
              <ul>
                <li className="text-gray-500 px-4 py-2">No results found</li>
              </ul>
            </div>
          )}
        </div>

        {/* Notification Icon */}
        <button className="bg-white rounded-lg p-2.5 shadow-sm hover:shadow-md focus:outline-none" aria-label="Notifications">
          <FaBell className="h-4 w-4 text-gray-600" />
        </button>
      </div>
    </header>
  );
};

export default Header;
