// src/pages/Analysis.jsx

import React, { useState, useEffect, useRef } from 'react';
import axios from 'axios';
import ReactMarkdown from 'react-markdown';
import rehypeSanitize from 'rehype-sanitize';
import { FaBolt } from 'react-icons/fa';

/**
 * EXACT copy of your AccordionSection from the Dashboard:
 */
const AccordionSection = ({ title, badges = [], children }) => {
  const [isOpen, setIsOpen] = useState(false);

  return (
        <div className="border border-gray-200 bg-white rounded-lg">
        <button
        className="w-full text-left py-2 px-4 flex justify-between items-center focus:outline-none"
        onClick={() => setIsOpen(!isOpen)}
        >
        <div className="flex items-center">
            <span className="text-lg font-semibold text-gray-800">{title}</span>
            <div className="ml-2 flex space-x-2">
            {badges.map((badge, index) => (
                <span
                key={index}
                className={
                    'text-xs font-semibold px-2 py-1 rounded-full ' +
                    (badge.type === 'vulnerability'
                    ? 'bg-red-100 text-red-800'
                    : badge.type === 'warning'
                    ? 'bg-yellow-100 text-yellow-800'
                    : 'bg-green-100 text-green-800')
                }
                >
                {badge.label}
                </span>
            ))}
            </div>
        </div>
        <span className="text-gray-600">{isOpen ? '-' : '+'}</span>
        </button>
        {isOpen && <div className="py-4 px-4">{children}</div>}
    </div>
  );
};

const aiAvatar = `${supportherowp.pluginUrl}assets/images/logo.png`;

const Analysis = () => {
  // 1) Histories for all stored scans
  const [histories, setHistories] = useState([]);
  const [loading, setLoading] = useState(false);
  const [error, setError] = useState(null);

  // 2) Chat states
  const [chatMessages, setChatMessages] = useState(() => {
    const saved = localStorage.getItem('supportherowp_chat_messages');
    return saved ? JSON.parse(saved) : [];
  });
  const [chatInput, setChatInput] = useState('');
  const [chatLoading, setChatLoading] = useState(false);
  const [chatError, setChatError] = useState(null);
  const chatEndRef = useRef(null);

  /**
   * On mount, fetch the scan histories.
   */
  useEffect(() => {
    async function fetchHistories() {
      setLoading(true);
      setError(null);
      try {
        const params = new URLSearchParams();
        params.append('action', 'supportherowp_get_scan_histories');
        params.append('nonce', supportherowp.nonce);

        const resp = await axios.post(supportherowp.ajaxurl, params, {
          headers: { 'Content-Type': 'application/x-www-form-urlencoded' },
        });

        if (resp.data.success) {
          // data: array of {id, user_id, scan_data_json, created_at}
          setHistories(resp.data.data || []);
        } else {
          setError(resp.data.data || 'Unknown error retrieving histories.');
        }
      } catch (err) {
        setError(err.message || 'Error retrieving histories.');
      } finally {
        setLoading(false);
      }
    }

    fetchHistories();
  }, []);

  /**
   * Keep the chat in localStorage (same logic as Dashboard).
   */
  useEffect(() => {
    localStorage.setItem('supportherowp_chat_messages', JSON.stringify(chatMessages));
    if (chatEndRef.current) {
      chatEndRef.current.scrollIntoView({ behavior: 'smooth' });
    }
  }, [chatMessages]);

  /**
   *  Deleting a scan record
   */
  const handleDeleteHistory = async (id) => {
    if (!window.confirm('Are you sure you want to delete this scan history?')) return;
    try {
      const params = new URLSearchParams();
      params.append('action', 'supportherowp_delete_scan_history');
      params.append('nonce', supportherowp.nonce);
      params.append('history_id', id);

      const resp = await axios.post(supportherowp.ajaxurl, params, {
        headers: { 'Content-Type': 'application/x-www-form-urlencoded' },
      });
      if (resp.data.success) {
        setHistories((prev) => prev.filter((x) => x.id !== String(id)));
      } else {
        alert(resp.data.data || 'Delete failed');
      }
    } catch (err) {
      alert(err.message || 'Delete error');
    }
  };

  /**
   *  Chat send
   */
  const handleSendMessage = async () => {
    if (!chatInput.trim()) return;
    const userMsg = { sender: 'user', message: chatInput.trim() };
    setChatMessages((p) => [...p, userMsg]);
    setChatInput('');
    setChatLoading(true);
    setChatError(null);

    try {
      const params = new URLSearchParams();
      params.append('action', 'supportherowp_chat');
      params.append('nonce', supportherowp.chat_nonce);
      params.append('message', userMsg.message);

      const resp = await axios.post(supportherowp.ajaxurl, params, {
        headers: { 'Content-Type': 'application/x-www-form-urlencoded' },
      });
      if (resp.data.success) {
        const aiMsg = { sender: 'ai', message: resp.data.data.reply };
        setChatMessages((p) => [...p, aiMsg]);
      } else {
        setChatError(resp.data.data || 'Unknown error occurred.');
      }
    } catch (err) {
      setChatError(err.message || 'An unexpected error occurred.');
    } finally {
      setChatLoading(false);
    }
  };

  // Loading / Error states
  if (loading) {
    return <div className="p-6">Loading scan histories...</div>;
  }
  if (error) {
    return <div className="p-6 text-red-500">Error: {error}</div>;
  }
  if (histories.length === 0) {
    return (
      <div className="p-6">
        <p>No scan histories found. Go to <strong>Dashboard</strong> to run your first scan!</p>
      </div>
    );
  }

  // Renders the sub-accordion for each main category: plugins, themes, etc.
  function renderScanSection(sr, type) {
    const badges = [];
    if (type === 'plugins') {
      if (sr.vulnerable_plugins?.length) {
        badges.push({ label: `${sr.vulnerable_plugins.length} Vulnerability`, type: 'vulnerability' });
      } else {
        badges.push({ label: 'All Good', type: 'good' });
      }
      if (sr.outdated_plugins?.length) {
        badges.push({ label: `${sr.outdated_plugins.length} Outdated`, type: 'warning' });
      }
      if (sr.inactive_plugins?.length) {
        badges.push({ label: `${sr.inactive_plugins.length} Inactive`, type: 'warning' });
      }
    }
    else if (type === 'themes') {
      if (sr.vulnerable_themes?.length) {
        badges.push({ label: `${sr.vulnerable_themes.length} Vulnerability`, type: 'vulnerability' });
      } else {
        badges.push({ label: 'All Good', type: 'good' });
      }
      if (sr.outdated_themes?.length) {
        badges.push({ label: `${sr.outdated_themes.length} Outdated`, type: 'warning' });
      }
      if (sr.inactive_themes?.length) {
        badges.push({ label: `${sr.inactive_themes.length} Inactive`, type: 'warning' });
      }
    }
    else if (type === 'database') {
      if (sr.unoptimized_tables?.length) {
        badges.push({ label: `${sr.unoptimized_tables.length} Unoptimized`, type: 'warning' });
      } else {
        badges.push({ label: 'Optimized', type: 'good' });
      }
    }
    else if (type === 'files') {
      let count = 0;
      if (sr.suspicious_files) count += sr.suspicious_files.length;
      if (sr.modified_core_files) count += sr.modified_core_files.length;
      if (count > 0) {
        badges.push({ label: `${count} Issue(s)`, type: 'vulnerability' });
      } else {
        badges.push({ label: 'All Clear', type: 'good' });
      }
    }
    else if (type === 'performance') {
      if (sr.performance_issues?.length) {
        badges.push({ label: `${sr.performance_issues.length} Issue(s)`, type: 'warning' });
      } else {
        badges.push({ label: 'Optimal', type: 'good' });
      }
    }
    else if (type === 'security') {
      if (sr.security_issues?.length) {
        badges.push({ label: `${sr.security_issues.length} Issue(s)`, type: 'vulnerability' });
      } else {
        badges.push({ label: 'Secure', type: 'good' });
      }
    }

    return (
      <AccordionSection title={getSectionTitle(type)} badges={badges}>
        {renderDetailedSection(sr, type)}
      </AccordionSection>
    );
  }

  // EXACT code from your Dashboard for "detailed items"
  function renderDetailedSection(sd, sectionType) {
    // This is exactly the logic from your "renderDetailedResults" or similar
    // We'll replicate it quickly:

    if (sectionType === 'plugins' || sectionType === 'themes') {
      return (
        <div className="space-y-4">
          {/* Outdated Items */}
          {(sd.outdated_plugins || sd.outdated_themes) ? (
            <div>
              <h4 className="font-semibold text-gray-700">Outdated Items:</h4>
              <ul className="list-disc list-inside text-sm text-gray-700">
                {sd.outdated_plugins?.map((pl, i) => (
                  <li key={i}>
                    <strong>{pl.name}</strong> (Current: {pl.current_version}, Latest: {pl.latest_version}){' '}
                    <a href={pl.update_url} target="_blank" rel="noopener noreferrer" className="text-blue-500">
                      Update Now
                    </a>
                  </li>
                ))}
                {sd.outdated_themes?.map((th, i) => (
                  <li key={i}>
                    <strong>{th.name}</strong> (Current: {th.current_version}, Latest: {th.latest_version}){' '}
                    <a href={th.update_url} target="_blank" rel="noopener noreferrer" className="text-blue-500">
                      Update Now
                    </a>
                  </li>
                ))}
              </ul>
            </div>
          ) : (
            <p className="text-sm text-green-600">All items are up to date.</p>
          )}

          {/* Inactive Items */}
          {(sd.inactive_plugins || sd.inactive_themes) && (
            <div>
              <h4 className="font-semibold text-gray-700">Inactive Items:</h4>
              <ul className="list-disc list-inside text-sm text-gray-700">
                {sd.inactive_plugins?.map((ip, i) => (
                  <li key={i}>
                    <strong>{ip.name}</strong> (Version: {ip.version})
                  </li>
                ))}
                {sd.inactive_themes?.map((it, i) => (
                  <li key={i}>
                    <strong>{it.name}</strong> (Version: {it.version})
                  </li>
                ))}
              </ul>
            </div>
          )}

          {/* Potentially Vulnerable Items */}
          {(sd.vulnerable_plugins || sd.vulnerable_themes) && (
            <div>
              <h4 className="font-semibold text-gray-700">Potentially Vulnerable Items:</h4>
              <ul className="list-disc list-inside text-sm text-gray-700">
                {sd.vulnerable_plugins?.map((vp, i) => (
                  <li key={i}>
                    <strong>{vp.name}</strong> (Version: {vp.version})
                    <ul className="list-disc list-inside text-xs text-red-500 mt-1">
                      {vp.suspicious_files.map((sf, j) => (
                        <li key={j}>
                          <code>{sf.file}</code> pattern: <em>{sf.pattern_matched}</em>
                        </li>
                      ))}
                    </ul>
                  </li>
                ))}
                {sd.vulnerable_themes?.map((vt, i) => (
                  <li key={i}>
                    <strong>{vt.name}</strong> (Version: {vt.version})
                    <ul className="list-disc list-inside text-xs text-red-500 mt-1">
                      {vt.suspicious_files.map((sf, j) => (
                        <li key={j}>
                          <code>{sf.file}</code> pattern: <em>{sf.pattern_matched}</em>
                        </li>
                      ))}
                    </ul>
                  </li>
                ))}
              </ul>
            </div>
          )}
        </div>
      );
    }
    else if (sectionType === 'database') {
      return (
        <div>
          {sd.unoptimized_tables?.length > 0 ? (
            <div>
              <h4 className="font-semibold text-gray-700">Unoptimized Tables:</h4>
              <ul className="list-disc list-inside text-sm text-gray-700">
                {sd.unoptimized_tables.map((tbl, i) => (
                  <li key={i}>
                    <strong>{tbl.name}</strong> - Overhead: {tbl.overhead} bytes
                  </li>
                ))}
              </ul>
            </div>
          ) : (
            <p className="text-sm text-green-600">All tables are optimized.</p>
          )}
        </div>
      );
    }
    else if (sectionType === 'files') {
      return (
        <div className="space-y-4">
          {/* Suspicious Files */}
          {sd.suspicious_files?.length > 0 && (
            <div>
              <h4 className="font-semibold text-gray-700">Suspicious Files:</h4>
              <ul className="list-disc list-inside text-sm text-gray-700">
                {sd.suspicious_files.map((f, i) => (
                  <li key={i}>
                    <code>{f.file}</code> - {f.reason || `pattern: ${f.pattern_matched}`}
                  </li>
                ))}
              </ul>
            </div>
          )}

          {/* Modified Core Files */}
          {sd.modified_core_files?.length > 0 && (
            <div>
              <h4 className="font-semibold text-gray-700 mt-4">Modified Core Files:</h4>
              <ul className="list-disc list-inside text-sm text-gray-700">
                {sd.modified_core_files.map((mf, i) => (
                  <li key={i}>
                    <code>{mf.file}</code> - {mf.description}
                  </li>
                ))}
              </ul>
            </div>
          )}
        </div>
      );
    }
    else if (sectionType === 'performance') {
      return (
        <div>
          {sd.performance_issues?.length > 0 ? (
            <div>
              <h4 className="font-semibold text-gray-700">Performance Issues:</h4>
              <ul className="list-disc list-inside text-sm text-gray-700">
                {sd.performance_issues.map((pi, i) => (
                  <li key={i}>
                    <strong>{pi.issue}</strong> - {pi.recommendation}
                  </li>
                ))}
              </ul>
            </div>
          ) : (
            <p className="text-sm text-green-600">No performance issues found.</p>
          )}
        </div>
      );
    }
    else if (sectionType === 'security') {
      return (
        <div>
          {sd.security_issues?.length > 0 ? (
            <div>
              <h4 className="font-semibold text-gray-700">Security Issues:</h4>
              <ul className="list-disc list-inside text-sm text-gray-700">
                {sd.security_issues.map((issue, i) => (
                  <li key={i}>
                    <strong>{issue.issue}</strong>
                    {issue.details?.length > 0 && (
                      <ul className="list-disc list-inside text-xs text-red-500 mt-1">
                        {issue.details.map((det, j) => (
                          <li key={j}>
                            {det.path ? <>Path: {det.path}, </> : null}
                            {det.permissions ? <>Permissions: {det.permissions}, </> : null}
                            {det.username ? <>User: {det.username}, </> : null}
                            {det.email ? <>Email: {det.email}, </> : null}
                            {det.last_change ? <>Last Change: {det.last_change}</> : null}
                          </li>
                        ))}
                      </ul>
                    )}
                    {issue.recommendation && (
                      <p className="text-xs text-gray-700 mt-1">{issue.recommendation}</p>
                    )}
                  </li>
                ))}
              </ul>
            </div>
          ) : (
            <p className="text-sm text-green-600">Everything looks secure.</p>
          )}
        </div>
      );
    }
    return <p className="text-sm text-gray-500">No data in this section.</p>;
  }

  function getSectionTitle(type) {
    if (type === 'plugins') return 'Plugins Analysis';
    if (type === 'themes') return 'Themes Analysis';
    if (type === 'database') return 'Database Optimization';
    if (type === 'files') return 'File System Scanning';
    if (type === 'performance') return 'Performance Metrics';
    if (type === 'security') return 'Security Checks';
    return 'Analysis';
  }

  // Renders entire scan record as an accordion, each sub-section is its own sub-accordion
  return (
    <div className="p-6 bg-[#f9f9f9] flex flex-row gap-6 h-screen font-poppins overflow-auto">

      {/* LEFT: Histories */}
      <div className="flex-1 space-y-6">
        <h2 className="text-xl font-semibold text-gray-800 -mb-4">Analysis Histories</h2>
        
        {histories.map((row) => {
          let parsed = null;
          try {
            parsed = row.scan_data_json ? JSON.parse(row.scan_data_json) : null;
          } catch (e) {
            // parse fail => skip or show error
          }

          return (
            <AccordionSection
              key={row.id}
              title={`Scan #${row.id} • ${new Date(row.created_at).toLocaleString()}`}
            >
              {/* Delete button */}
              <div className="flex justify-end mb-2">
                <button
                  onClick={() => handleDeleteHistory(row.id)}
                  className="text-sm text-red-600"
                >
                  Delete
                </button>
              </div>

              {!parsed ? (
                <p className="text-red-500">Corrupted data or parse error</p>
              ) : (
                <div className="space-y-4">

                  {/* Sub-accordion for each main category */}
                  {renderScanSection(parsed.scan_results.plugins, 'plugins')}
                  {renderScanSection(parsed.scan_results.themes, 'themes')}
                  {renderScanSection(parsed.scan_results.database, 'database')}
                  {renderScanSection(parsed.scan_results.files, 'files')}
                  {renderScanSection(parsed.scan_results.performance, 'performance')}
                  {renderScanSection(parsed.scan_results.security, 'security')}

                  {/* If you also want to show AI Analysis / Recommendations from the scan */}
                  <AccordionSection title="AI Analysis & Recommendations">
                    <div className="space-y-4">
                      {/* AI Analysis */}
                      <section>
                        <h3 className="text-md font-semibold text-gray-800">AI Analysis</h3>
                        <ReactMarkdown rehypePlugins={[rehypeSanitize]} className="prose prose-sm text-gray-700">
                          {parsed.ai_analysis || ''}
                        </ReactMarkdown>
                      </section>

                      {/* Recommendations */}
                      <section>
                        <h3 className="text-md font-semibold text-gray-800">Recommendations</h3>
                        {parsed.recommendations?.security && (
                          <div className="mt-2">
                            <h4 className="text-sm font-semibold text-gray-700">Security Recommendations:</h4>
                            <ReactMarkdown rehypePlugins={[rehypeSanitize]} className="prose prose-sm text-gray-700">
                              {parsed.recommendations.security}
                            </ReactMarkdown>
                          </div>
                        )}
                        {parsed.recommendations?.performance && (
                          <div className="mt-4">
                            <h4 className="text-sm font-semibold text-gray-700">Performance Recommendations:</h4>
                            <ReactMarkdown rehypePlugins={[rehypeSanitize]} className="prose prose-sm text-gray-700">
                              {parsed.recommendations.performance}
                            </ReactMarkdown>
                          </div>
                        )}
                      </section>
                    </div>
                  </AccordionSection>
                </div>
              )}
            </AccordionSection>
          );
        })}
      </div>

      {/* RIGHT: AI Chat */}
        <div className="w-1/3 flex flex-col max-h-[75vh]">
          <h2 className="text-xl font-semibold text-gray-800 mb-2">Chat with SupportHeroWP</h2>
          <div className="bg-white p-4 rounded-lg flex flex-col h-auto shadow">
            <div className="flex-1 overflow-auto mb-4">
              {/* Welcome Message */}
              {chatMessages.length === 0 && (
                <div className="flex justify-start mb-4">
                  <img src={aiAvatar} alt="AI Avatar" className="w-20 h-16 mr-4" />
                  <div className="bg-orange-100 p-4 rounded-lg max-w-xs text-sm text-gray-700 shadow">
                    <p className="font-semibold">Welcome to SupportHeroWP!</p>
                    <p>
                      Start by scanning your site using the <strong>Dashboard</strong>. 
                      You can also ask me questions about your scans and how to resolve issues!
                    </p>
                  </div>
                </div>
              )}

              {/* Chat Messages */}
              {chatMessages.map((msg, index) => (
                <div key={index} className={`mb-2 flex ${msg.sender === 'user' ? 'justify-end' : 'justify-start'}`}>
                  {msg.sender === 'ai' && (
                    <img src={aiAvatar} alt="AI Avatar" className="w-20 h-16 mr-2" />
                  )}
                  <div
                    className={`p-3 rounded-lg shadow ${
                      msg.sender === 'user' ? 'bg-orange-500 text-white' : 'bg-gray-200 text-gray-800'
                    } max-w-xs break-words`}
                  >
                    {msg.sender === 'ai' ? (
                      <ReactMarkdown rehypePlugins={[rehypeSanitize]}>{msg.message}</ReactMarkdown>
                    ) : (
                      msg.message
                    )}
                  </div>
                </div>
              ))}

              {/* Typing Indicator */}
              {chatLoading && (
                <div className="flex justify-start mb-2">
                  <img src={aiAvatar} alt="AI Avatar" className="w-20 h-16 mr-2" />
                  <div className="p-2 rounded-lg bg-gray-200 text-gray-800 max-w-xs italic">
                    SupportHeroWP is typing...
                  </div>
                </div>
              )}
              <div ref={chatEndRef} />
            </div>

            {/* Input Section */}
            <div className="flex">
              <input
                type="text"
                value={chatInput}
                onChange={(e) => setChatInput(e.target.value)}
                className="flex-1 border !border-[#efefef] rounded-lg mr-1 px-6 py-4 focus:outline-none focus:ring-2 focus:ring-orange-500 text-sm"
                placeholder="Type your message..."
                onKeyDown={(e) => {
                  if (e.key === 'Enter' && !e.shiftKey) {
                    e.preventDefault();
                    handleSendMessage();
                  }
                }}
                disabled={chatLoading}
              />
              <button
                onClick={handleSendMessage}
                className="bg-orange-500 text-white px-2 py-2 rounded-lg flex items-center justify-center hover:bg-orange-600 transition"
                disabled={chatLoading}
              >
                <svg
                  xmlns="http://www.w3.org/2000/svg"
                  width="24"
                  height="24"
                  viewBox="0 0 24 24"
                  style={{ fill: 'white', transform: '', msFilter: '' }}
                >
                  <path d="M20.56 3.34a1 1 0 0 0-1-.08l-17 8a1 1 0 0 0-.57.92 1 1 0 0 0 .6.9L8 15.45v6.72L13.84 18l4.76 2.08a.93.93 0 0 0 .4.09 1 1 0 0 0 .52-.15 1 1 0 0 0 .48-.79l1-15a1 1 0 0 0-.44-.89zM18.1 17.68l-5.27-2.31L16 9.17l-7.65 4.25-2.93-1.29 13.47-6.34z"></path>
                </svg>
              </button>
            </div>
            {chatError && <p className="text-red-500 mt-2">{chatError}</p>}
          </div>
        </div>
    </div>
  );
};

export default Analysis;
