// src/pages/Dashboard.jsx

import React, { useState, useEffect, useRef } from 'react';
import axios from 'axios';
import ReactMarkdown from 'react-markdown';
import rehypeSanitize from 'rehype-sanitize';
import { FaBolt } from 'react-icons/fa';

const aiAvatar = `${supportherowp.pluginUrl}assets/images/logo.png`;

const AccordionSection = ({ title, badges = [], children }) => {
  const [isOpen, setIsOpen] = useState(false);

  return (
    <div className="border-b border-gray-200">
      <button
        className="w-full text-left py-2 flex justify-between items-center focus:outline-none"
        onClick={() => setIsOpen(!isOpen)}
      >
        <div className="flex items-center">
          <span className="text-lg font-semibold text-gray-800">{title}</span>
          {/* Uncommented badges */}
          <div className="ml-2 flex space-x-2">
            {badges.map((badge, index) => (
              <span
                key={index}
                className={
                  'text-xs font-semibold px-2 py-1 rounded-full ' +
                  (badge.type === 'vulnerability'
                    ? 'bg-red-100 text-red-800'
                    : badge.type === 'warning'
                    ? 'bg-yellow-100 text-yellow-800'
                    : 'bg-green-100 text-green-800')
                }
              >
                {badge.label}
              </span>
            ))}
          </div> 
        </div>
        <span className="text-gray-600">{isOpen ? '-' : '+'}</span>
      </button>
      {isOpen && <div className="py-2">{children}</div>}
    </div>
  );
};

const Dashboard = () => {
  const [scanResult, setScanResult] = useState(() => {
    const lastScan = localStorage.getItem('supportherowp_last_scan');
    return lastScan ? JSON.parse(lastScan) : null;
  });
  const [loading, setLoading] = useState(false);
  const [progress, setProgress] = useState(0); // Progress state for loader
  const [error, setError] = useState(null);

  // Chat States
  const [chatMessages, setChatMessages] = useState(() => {
    const saved = localStorage.getItem('supportherowp_chat_messages');
    return saved ? JSON.parse(saved) : [];
  });
  const [chatInput, setChatInput] = useState('');
  const [chatLoading, setChatLoading] = useState(false);
  const [chatError, setChatError] = useState(null);
  const chatEndRef = useRef(null);

  useEffect(() => {
    localStorage.setItem('supportherowp_chat_messages', JSON.stringify(chatMessages));
    if (chatEndRef.current) {
      chatEndRef.current.scrollIntoView({ behavior: 'smooth' });
    }
  }, [chatMessages]);

  const handleScan = async () => {
    setLoading(true);
    setError(null);
    setProgress(0); // Reset progress at the start

    // Start progress increment
    const progressInterval = setInterval(() => {
      setProgress((prev) => {
        if (prev >= 95) {
          return prev; // Stop incrementing beyond 95%
        }
        return prev + 1; // Increment by 1%
      });
    }, 100); // Increment every 100ms

    try {
      const params = new URLSearchParams();
      params.append('action', 'supportherowp_scan');
      params.append('nonce', supportherowp.nonce);

      const response = await axios.post(supportherowp.ajaxurl, params, {
        headers: { 'Content-Type': 'application/x-www-form-urlencoded' },
      });

      if (response.data.success) {
        const data = response.data.data;
        setScanResult(data);
        const summary = generateBriefSummary(data);
        setChatMessages((prev) => [...prev, { sender: 'ai', message: summary }]);
        await storeScanData(data);

        // Save scan results to localStorage
        localStorage.setItem('supportherowp_last_scan', JSON.stringify(data));
      } else {
        setError(response.data.data || 'Unknown error occurred.');
      }
    } catch (err) {
      if (err.response) setError(err.response.data.data || 'Server error occurred.');
      else if (err.request) setError('No response from server.');
      else setError(err.message || 'An unexpected error occurred.');
    } finally {
      clearInterval(progressInterval); // Clear the interval when scan completes or fails
      setProgress(100); // Set progress to 100%
      setTimeout(() => {
        setProgress(0); // Reset progress after a short delay
        setLoading(false);
      }, 500); // Delay to show full progress bar
    }
  };

  const generateBriefSummary = (scanData) => {
    const sr = scanData.scan_results;
    let msg = "Hello! I've completed the scan. Here’s a brief summary:\n\n";
    let secCount = 0;
    if (sr.security && sr.security.security_issues) secCount = sr.security.security_issues.length;
    if (secCount > 0) msg += `- **Security:** Found ${secCount} issue(s).\n`;
    else msg += '- **Security:** All systems secure.\n';
    let perfCount = 0;
    if (sr.performance && sr.performance.performance_issues) perfCount = sr.performance.performance_issues.length;
    if (perfCount > 0) msg += `- **Performance:** Found ${perfCount} performance issue(s).\n`;
    else msg += '- **Performance:** Your website is performing optimally.\n';
    msg += '\nIf you have questions, just ask!';
    return msg;
  };

  const storeScanData = async (data) => {
    try {
      const params = new URLSearchParams();
      params.append('action', 'supportherowp_store_scan_data');
      params.append('nonce', supportherowp.nonce);
      params.append('scan_data', JSON.stringify(data));

      const resp = await axios.post(supportherowp.ajaxurl, params, {
        headers: { 'Content-Type': 'application/x-www-form-urlencoded' },
      });
      if (!resp.data.success) console.error('Failed to store scan data:', resp.data.data);
    } catch (err) {
      console.error('Error storing scan data:', err);
    }
  };

  const handleSendMessage = async () => {
    if (!chatInput.trim()) return;
    const userMsg = { sender: 'user', message: chatInput.trim() };
    setChatMessages((prev) => [...prev, userMsg]);
    setChatInput('');
    setChatLoading(true);
    setChatError(null);
    try {
      const params = new URLSearchParams();
      params.append('action', 'supportherowp_chat');
      params.append('nonce', supportherowp.chat_nonce);
      params.append('message', userMsg.message);

      const resp = await axios.post(supportherowp.ajaxurl, params, {
        headers: { 'Content-Type': 'application/x-www-form-urlencoded' },
      });
      if (resp.data.success) {
        const aiMsg = { sender: 'ai', message: resp.data.data.reply };
        setChatMessages((prev) => [...prev, aiMsg]);
      } else {
        setChatError(resp.data.data || 'Unknown error occurred.');
      }
    } catch (err) {
      if (err.response) setChatError(err.response.data.data || 'Server error occurred.');
      else if (err.request) setChatError('No response from server.');
      else setChatError(err.message || 'An unexpected error occurred.');
    } finally {
      setChatLoading(false);
    }
  };

  // Commented out "Update Now" buttons as per your current requirement
  /*
  const handleUpdatePlugin = async (pluginName) => {
    if (!window.confirm(`Are you sure you want to update "${pluginName}"?`)) return;

    try {
      const params = new URLSearchParams();
      params.append('action', 'supportherowp_update_plugin');
      params.append('nonce', supportherowp.nonce);
      params.append('plugin_name', pluginName);

      const response = await axios.post(supportherowp.ajaxurl, params, {
        headers: { 'Content-Type': 'application/x-www-form-urlencoded' },
      });

      if (response.data.success) {
        alert(`"${pluginName}" has been updated successfully.`);
        // Optionally, refresh the scan results after updating
        handleScan();
      } else {
        alert(response.data.data || 'Failed to update the plugin.');
      }
    } catch (err) {
      console.error(err);
      alert('An error occurred while updating the plugin.');
    }
  };
  */

  const renderScanResults = (sd, sectionType) => {
    const badges = [];
    if (sectionType === 'plugins') {
      if (sd.vulnerable_plugins && sd.vulnerable_plugins.length > 0)
        badges.push({ label: `${sd.vulnerable_plugins.length} Vulnerability`, type: 'vulnerability' });
      else badges.push({ label: 'All Good', type: 'good' });
      if (sd.outdated_plugins && sd.outdated_plugins.length > 0)
        badges.push({ label: `${sd.outdated_plugins.length} Outdated`, type: 'warning' });
      if (sd.inactive_plugins && sd.inactive_plugins.length > 0)
        badges.push({ label: `${sd.inactive_plugins.length} Inactive`, type: 'warning' });
    } else if (sectionType === 'themes') {
      if (sd.vulnerable_themes && sd.vulnerable_themes.length > 0)
        badges.push({ label: `${sd.vulnerable_themes.length} Vulnerability`, type: 'vulnerability' });
      else badges.push({ label: 'All Good', type: 'good' });
      if (sd.outdated_themes && sd.outdated_themes.length > 0)
        badges.push({ label: `${sd.outdated_themes.length} Outdated`, type: 'warning' });
      if (sd.inactive_themes && sd.inactive_themes.length > 0)
        badges.push({ label: `${sd.inactive_themes.length} Inactive`, type: 'warning' });
    } else if (sectionType === 'database') {
      if (sd.unoptimized_tables && sd.unoptimized_tables.length > 0)
        badges.push({ label: `${sd.unoptimized_tables.length} Unoptimized`, type: 'warning' });
      else badges.push({ label: 'Optimized', type: 'good' });
    } else if (sectionType === 'files') {
      let c = 0;
      if (sd.suspicious_files) c += sd.suspicious_files.length;
      if (sd.modified_core_files) c += sd.modified_core_files.length;
      if (c > 0) badges.push({ label: `${c} Issue(s)`, type: 'vulnerability' });
      else badges.push({ label: 'All Clear', type: 'good' });
    } else if (sectionType === 'performance') {
      if (sd.performance_issues && sd.performance_issues.length > 0)
        badges.push({ label: `${sd.performance_issues.length} Issue(s)`, type: 'warning' });
      else badges.push({ label: 'Optimal', type: 'good' });
    } else if (sectionType === 'security') {
      if (sd.security_issues && sd.security_issues.length > 0)
        badges.push({ label: `${sd.security_issues.length} Issue(s)`, type: 'vulnerability' });
      else badges.push({ label: 'Secure', type: 'good' });
    }
    return (
      <AccordionSection title={getSectionTitle(sectionType)} badges={badges}>
        {renderDetailedResults(sd, sectionType)}
      </AccordionSection>
    );
  };

  const getSectionTitle = (type) => {
    if (type === 'plugins') return 'Plugins Analysis';
    if (type === 'themes') return 'Themes Analysis';
    if (type === 'database') return 'Database Optimization';
    if (type === 'files') return 'File System Scanning';
    if (type === 'performance') return 'Performance Metrics';
    if (type === 'security') return 'Security Checks';
    return 'Analysis';
  };

  const renderDetailedResults = (sd, sectionType) => {
    return (
      <div className="space-y-4">
        {sd.outdated_plugins || sd.outdated_themes ? (
          <div>
            <h4 className="font-semibold text-gray-700">Outdated Items:</h4>
            <ul className="list-disc list-inside text-sm text-gray-700">
              {sd.outdated_plugins &&
                sd.outdated_plugins.map((pl, i) => (
                  <li key={i} className="flex justify-between items-center">
                    <span>
                      <strong>{pl.name}</strong> (Current: {pl.current_version}, Latest: {pl.latest_version})
                    </span>
                    {/* <a
                      href={pl.update_url}
                      target="_blank"
                      rel="noopener noreferrer"
                      className="text-blue-500 hover:underline text-xs"
                    >
                      Update Now
                    </a> */}
                  </li>
                ))}
              {sd.outdated_themes &&
                sd.outdated_themes.map((th, i) => (
                  <li key={i} className="flex justify-between items-center">
                    <span>
                      <strong>{th.name}</strong> (Current: {th.current_version}, Latest: {th.latest_version})
                    </span>
                    {/* <a
                      href={th.update_url}
                      target="_blank"
                      rel="noopener noreferrer"
                      className="text-blue-500 hover:underline text-xs"
                    >
                      Update Now
                    </a> */}
                  </li>
                ))}
            </ul>
          </div>
        ) : (
          <p className="text-sm text-green-600">All items are up to date.</p>
        )}

        {sd.inactive_plugins || sd.inactive_themes ? (
          <div>
            <h4 className="font-semibold text-gray-700">Inactive Items:</h4>
            <ul className="list-disc list-inside text-sm text-gray-700">
              {sd.inactive_plugins &&
                sd.inactive_plugins.map((ip, i) => (
                  <li key={i} className="flex justify-between items-center">
                    <span>
                      <strong>{ip.name}</strong> (Version: {ip.version})
                    </span>
                    {/* <button
                      onClick={() => handleUpdatePlugin(ip.name)}
                      className="text-blue-500 hover:underline text-xs"
                    >
                      Update Now
                    </button> */}
                  </li>
                ))}
              {sd.inactive_themes &&
                sd.inactive_themes.map((it, i) => (
                  <li key={i} className="flex justify-between items-center">
                    <span>
                      <strong>{it.name}</strong> (Version: {it.version})
                    </span>
                    {/* <button
                      onClick={() => handleUpdatePlugin(it.name)}
                      className="text-blue-500 hover:underline text-xs"
                    >
                      Update Now
                    </button> */}
                  </li>
                ))}
            </ul>
          </div>
        ) : null}

        {sd.vulnerable_plugins || sd.vulnerable_themes ? (
          <div>
            <h4 className="font-semibold text-gray-700">Potentially Vulnerable Items:</h4>
            <ul className="list-disc list-inside text-sm text-gray-700">
              {sd.vulnerable_plugins &&
                sd.vulnerable_plugins.map((vp, i) => (
                  <li key={i}>
                    <strong>{vp.name}</strong> (Version: {vp.version})
                    <ul className="list-disc list-inside text-xs text-red-500 mt-1">
                      {vp.suspicious_files.map((sf, j) => (
                        <li key={j}>
                          <code>{sf.file}</code> pattern: <em>{sf.pattern_matched}</em>
                        </li>
                      ))}
                    </ul>
                  </li>
                ))}
              {sd.vulnerable_themes &&
                sd.vulnerable_themes.map((vt, i) => (
                  <li key={i}>
                    <strong>{vt.name}</strong> (Version: {vt.version})
                    <ul className="list-disc list-inside text-xs text-red-500 mt-1">
                      {vt.suspicious_files.map((sf, j) => (
                        <li key={j}>
                          <code>{sf.file}</code> pattern: <em>{sf.pattern_matched}</em>
                        </li>
                      ))}
                    </ul>
                  </li>
                ))}
            </ul>
          </div>
        ) : null}

        {sd.unoptimized_tables && sd.unoptimized_tables.length > 0 ? (
          <div>
            <h4 className="font-semibold text-gray-700">Unoptimized Tables:</h4>
            <ul className="list-disc list-inside text-sm text-gray-700">
              {sd.unoptimized_tables.map((table, i) => (
                <li key={i}>
                  <strong>{table.name}</strong> - Overhead: {table.overhead} bytes
                </li>
              ))}
            </ul>
          </div>
        ) : null}

        {sd.suspicious_files || sd.modified_core_files ? (
          <div>
            {sd.suspicious_files && sd.suspicious_files.length > 0 ? (
              <div>
                <h4 className="font-semibold text-gray-700">Suspicious Files:</h4>
                <ul className="list-disc list-inside text-sm text-gray-700">
                  {sd.suspicious_files.map((f, i) => (
                    <li key={i}>
                      <code>{f.file}</code> - {f.reason || `pattern: ${f.pattern_matched}`}
                    </li>
                  ))}
                </ul>
              </div>
            ) : null}
            {sd.modified_core_files && sd.modified_core_files.length > 0 ? (
              <div className="mt-4">
                <h4 className="font-semibold text-gray-700">Modified Core Files:</h4>
                <ul className="list-disc list-inside text-sm text-gray-700">
                  {sd.modified_core_files.map((mf, i) => (
                    <li key={i}>
                      <code>{mf.file}</code> - {mf.description}
                    </li>
                  ))}
                </ul>
              </div>
            ) : null}
          </div>
        ) : null}

        {sd.performance_issues && sd.performance_issues.length > 0 ? (
          <div>
            <h4 className="font-semibold text-gray-700">Performance Issues:</h4>
            <ul className="list-disc list-inside text-sm text-gray-700">
              {sd.performance_issues.map((pi, i) => (
                <li key={i}>
                  <strong>{pi.issue}</strong> - {pi.recommendation}
                </li>
              ))}
            </ul>
          </div>
        ) : null}

        {sd.security_issues && sd.security_issues.length > 0 ? (
          <div>
            <h4 className="font-semibold text-gray-700">Security Issues:</h4>
            <ul className="list-disc list-inside text-sm text-gray-700">
              {sd.security_issues.map((issue, i) => (
                <li key={i}>
                  <strong>{issue.issue}</strong>
                  {issue.details && issue.details.length > 0 ? (
                    <ul className="list-disc list-inside text-xs text-red-500 mt-1">
                      {issue.details.map((det, j) => (
                        <li key={j}>
                          {det.path ? <span>Path: {det.path}, </span> : null}
                          {det.permissions ? <span>Permissions: {det.permissions}, </span> : null}
                          {det.username ? <span>User: {det.username}, </span> : null}
                          {det.email ? <span>Email: {det.email}, </span> : null}
                          {det.last_change ? <span>Last Change: {det.last_change}</span> : null}
                        </li>
                      ))}
                    </ul>
                  ) : null}
                  {issue.recommendation ? (
                    <p className="text-xs text-gray-700 mt-1">{issue.recommendation}</p>
                  ) : null}
                </li>
              ))}
            </ul>
          </div>
        ) : null}
      </div>
    )};

    const renderAISections = (d) => {
      return (
        <div className="space-y-6">
          <section>
            <h3 className="text-lg font-semibold text-gray-800">AI Analysis:</h3>
            <ReactMarkdown rehypePlugins={[rehypeSanitize]} className="prose prose-sm text-gray-700">
              {d.ai_analysis}
            </ReactMarkdown>
          </section>
          <section>
            <h3 className="text-lg font-semibold text-gray-800">Recommendations:</h3>
            {d.recommendations.security ? (
              <div className="mt-2">
                <h4 className="text-md font-semibold text-gray-700">Security Recommendations:</h4>
                <ReactMarkdown rehypePlugins={[rehypeSanitize]} className="prose prose-sm text-gray-700">
                  {d.recommendations.security}
                </ReactMarkdown>
              </div>
            ) : null}
            {d.recommendations.performance ? (
              <div className="mt-4">
                <h4 className="text-md font-semibold text-gray-700">Performance Recommendations:</h4>
                <ReactMarkdown rehypePlugins={[rehypeSanitize]} className="prose prose-sm text-gray-700">
                  {d.recommendations.performance}
                </ReactMarkdown>
              </div>
            ) : null}
          </section>
        </div>
      );
    };

    return (
      <div className="p-6 bg-[#f9f9f9] flex flex-col gap-6 h-screen font-poppins overflow-auto">
        <div className="flex-1 flex flex-row gap-6">
          {/* Left Column: Scan and Results */}
          <div className="flex-1 space-y-6">
            {/* Scan Section */}
            <section>
              <h2 className="text-xl font-semibold text-gray-800 mb-2">Analyze</h2>
              <div className="bg-white p-4 rounded-lg flex items-start justify-between shadow">
                <div className="flex items-start">
                  <div className="p-2 bg-orange-50 rounded-full mr-4">
                    <FaBolt className="h-6 w-6 text-black" />
                  </div>
                  <div>
                    <p className="text-lg font-semibold text-gray-800">Check website health!</p>
                    <p className="text-xs text-gray-500">Run through the files...</p>
                    {/* Removed the progress bar from here */}
                  </div>
                </div>
                <button
                  onClick={handleScan}
                  className={`${
                    loading ? 'bg-gray-300 cursor-not-allowed' : 'bg-orange-500 hover:bg-orange-600'
                  } text-white px-4 py-2 rounded-lg text-sm flex items-center justify-center transition`}
                  disabled={loading}
                >
                  {loading ? 'Scanning...' : 'Start'}
                </button>
              </div>
              {/* Moved Progress Bar below the scan section */}
              {loading && (
                <div className="bg-white p-4 rounded-lg shadow mt-2">
                  <p className="text-sm font-bold text-gray-600">Running through the files...</p>
                  <p className="text-sm font-normal text-gray-600">Progress: {progress}%</p>
                  <div className="w-full bg-gray-200 rounded-full h-2.5 mt-1">
                    <div
                      className="bg-orange-500 h-2.5 rounded-full transition-all duration-100"
                      style={{ width: `${progress}%` }}
                    ></div>
                  </div>
                </div>
              )}
            </section>

            {/* Error Message */}
            {error && <p className="text-red-500 mt-2">{error}</p>}

            {/* Scan Results */}
            {scanResult && (
              <>
                <div className="bg-white p-4 rounded-lg shadow">
                  {renderScanResults(scanResult.scan_results.plugins, 'plugins')}
                  {renderScanResults(scanResult.scan_results.themes, 'themes')}
                  {renderScanResults(scanResult.scan_results.database, 'database')}
                  {renderScanResults(scanResult.scan_results.files, 'files')}
                  {renderScanResults(scanResult.scan_results.performance, 'performance')}
                  {renderScanResults(scanResult.scan_results.security, 'security')}
                </div>
                <div className="bg-white p-4 rounded-lg shadow">
                  {renderAISections(scanResult)}
                </div>
              </>
            )}
          </div>

          {/* Right Column: Chat */}
          <div className="w-1/3 flex flex-col max-h-[75vh]">
            <h2 className="text-xl font-semibold text-gray-800 mb-2">Chat with SupportHeroWP</h2>
            <div className="bg-white p-4 rounded-lg flex flex-col h-auto shadow">
              <div className="flex-1 overflow-auto mb-4">
                {/* Welcome Message */}
                {chatMessages.length === 0 && (
                  <div className="flex justify-start mb-4">
                    <img src={aiAvatar} alt="AI Avatar" className="w-20 h-16 mr-4" />
                    <div className="bg-orange-100 p-4 rounded-lg max-w-xs text-sm text-gray-700 shadow">
                      <p className="font-semibold">Welcome to SupportHeroWP!</p>
                      <p>
                        Start by scanning your site using the <strong>Analyze</strong> section. 
                        You can also ask me questions about your scans and how to resolve issues!
                      </p>
                    </div>
                  </div>
                )}

                {/* Chat Messages */}
                {chatMessages.map((msg, index) => (
                  <div key={index} className={`mb-2 flex ${msg.sender === 'user' ? 'justify-end' : 'justify-start'}`}>
                    {msg.sender === 'ai' && (
                      <img src={aiAvatar} alt="AI Avatar" className="w-20 h-16 mr-2" />
                    )}
                    <div
                      className={`p-3 rounded-lg shadow ${
                        msg.sender === 'user' ? 'bg-orange-500 text-white' : 'bg-gray-200 text-gray-800'
                      } max-w-xs break-words`}
                    >
                      {msg.sender === 'ai' ? (
                        <ReactMarkdown rehypePlugins={[rehypeSanitize]}>{msg.message}</ReactMarkdown>
                      ) : (
                        msg.message
                      )}
                    </div>
                  </div>
                ))}

                {/* Typing Indicator */}
                {chatLoading && (
                  <div className="flex justify-start mb-2">
                    <img src={aiAvatar} alt="AI Avatar" className="w-20 h-16 mr-2" />
                    <div className="p-2 rounded-lg bg-gray-200 text-gray-800 max-w-xs italic">
                      SupportHeroWP is typing...
                    </div>
                  </div>
                )}
                <div ref={chatEndRef} />
              </div>

              {/* Input Section */}
              <div className="flex">
                <input
                  type="text"
                  value={chatInput}
                  onChange={(e) => setChatInput(e.target.value)}
                  className="flex-1 border !border-[#efefef] rounded-lg mr-1 px-6 py-4 focus:outline-none focus:ring-2 focus:ring-orange-500 text-sm"
                  placeholder="Type your message..."
                  onKeyDown={(e) => {
                    if (e.key === 'Enter' && !e.shiftKey) {
                      e.preventDefault();
                      handleSendMessage();
                    }
                  }}
                  disabled={chatLoading}
                />
                <button
                  onClick={handleSendMessage}
                  className="bg-orange-500 text-white px-2 py-2 rounded-lg flex items-center justify-center hover:bg-orange-600 transition"
                  disabled={chatLoading}
                >
                  <svg
                    xmlns="http://www.w3.org/2000/svg"
                    width="24"
                    height="24"
                    viewBox="0 0 24 24"
                    style={{ fill: 'white' }}
                  >
                    <path d="M20.56 3.34a1 1 0 0 0-1-.08l-17 8a1 1 0 0 0-.57.92 1 1 0 0 0 .6.9L8 15.45v6.72L13.84 18l4.76 2.08a.93.93 0 0 0 .4.09 1 1 0 0 0 .52-.15 1 1 0 0 0 .48-.79l1-15a1 1 0 0 0-.44-.89zM18.1 17.68l-5.27-2.31L16 9.17l-7.65 4.25-2.93-1.29 13.47-6.34z"></path>
                  </svg>
                </button>
              </div>
              {chatError && <p className="text-red-500 mt-2">{chatError}</p>}
            </div>
          </div>
        </div>
      </div>
    );
  };

  export default Dashboard;
