// src/pages/Settings.jsx

import React, { useState, useEffect } from 'react';
import axios from 'axios';
import { FaKey, FaEnvelope, FaSave } from 'react-icons/fa';

const Settings = () => {
  const [openaiKey, setOpenaiKey] = useState('');
  const [expertsEmail, setExpertsEmail] = useState('');
  const [loading, setLoading] = useState(false);
  const [updateLoading, setUpdateLoading] = useState(false);
  const [error, setError] = useState(null);
  const [updateError, setUpdateError] = useState(null);
  const [success, setSuccess] = useState(null);

  useEffect(() => {
    const fetchSettings = async () => {
      setLoading(true);
      setError(null);
      try {
        const params = new URLSearchParams();
        params.append('action', 'supportherowp_get_settings');
        params.append('nonce', supportherowp.nonce);

        const response = await axios.post(supportherowp.ajaxurl, params, {
          headers: { 'Content-Type': 'application/x-www-form-urlencoded' },
        });

        if (response.data.success) {
          const data = response.data.data;
          setOpenaiKey(data.openai_key);
          setExpertsEmail(data.experts_email);
        } else {
          setError(response.data.data || 'Failed to fetch settings.');
        }
      } catch (err) {
        if (err.response) setError(err.response.data.data || 'Server error occurred.');
        else if (err.request) setError('No response from server.');
        else setError(err.message || 'An unexpected error occurred.');
      } finally {
        setLoading(false);
      }
    };

    fetchSettings();
  }, []);

  const handleSubmit = async (e) => {
    e.preventDefault();
    setUpdateLoading(true);
    setUpdateError(null);
    setSuccess(null);

    // Validation
    if (!openaiKey.trim()) {
      setUpdateError('OpenAI API key is required.');
      setUpdateLoading(false);
      return;
    }

    if (!expertsEmail.trim()) {
      setUpdateError('Experts Email is required.');
      setUpdateLoading(false);
      return;
    }

    try {
      const params = new URLSearchParams();
      params.append('action', 'supportherowp_update_settings');
      params.append('nonce', supportherowp.nonce);
      params.append('openai_key', openaiKey.trim());
      params.append('experts_email', expertsEmail.trim());

      const response = await axios.post(supportherowp.ajaxurl, params, {
        headers: { 'Content-Type': 'application/x-www-form-urlencoded' },
      });

      if (response.data.success) {
        setSuccess(response.data.data || 'Settings updated successfully.');
      } else {
        setUpdateError(response.data.data || 'Failed to update settings.');
      }
    } catch (err) {
      if (err.response) setUpdateError(err.response.data.data || 'Server error occurred.');
      else if (err.request) setUpdateError('No response from server.');
      else setUpdateError(err.message || 'An unexpected error occurred.');
    } finally {
      setUpdateLoading(false);
    }
  };

  return (
    <div className="p-6 bg-[#f9f9f9] h-full font-poppins">
      <h2 className="text-2xl font-semibold text-gray-800 mb-6">Settings</h2>

      {/* Loading Indicator */}
      {loading ? (
        <p>Loading settings...</p>
      ) : error ? (
        <p className="text-red-500">{error}</p>
      ) : (
        <form onSubmit={handleSubmit}>
          {/* Bento Grid */}
          <div className="grid grid-cols-1 md:grid-cols-2 lg:grid-cols-3 gap-6">
            {/* OpenAI API Key Setting */}
            <div className="bg-white rounded-lg p-6 shadow flex flex-col">
              <div className="flex items-center mb-4">
                <FaKey className="text-orange-500 w-6 h-6 mr-2" />
                <h3 className="text-lg font-semibold text-gray-800">OpenAI API Key</h3>
              </div>
              <p className="text-sm text-gray-600 mb-2">Enter your OpenAI API key to enable AI features.</p>
              <input
                type="text"
                id="openai_key"
                name="openai_key"
                value={openaiKey}
                onChange={(e) => setOpenaiKey(e.target.value)}
                className="mt-1 mb-4 block w-full border border-gray-300 rounded-md shadow-sm p-2 focus:outline-none focus:ring-2 focus:ring-orange-500 focus:border-orange-500"
                placeholder="Enter your OpenAI API key"
              />
              {/* Optional: Additional actions or info can go here */}
            </div>

            {/* Experts Email Setting */}
            <div className="bg-white rounded-lg p-6 shadow flex flex-col">
              <div className="flex items-center mb-4">
                <FaEnvelope className="text-blue-500 w-6 h-6 mr-2" />
                <h3 className="text-lg font-semibold text-gray-800">Experts Email</h3>
              </div>
              <p className="text-sm text-gray-600 mb-2">Email address for expert support.</p>
              <input
                type="email"
                id="experts_email"
                name="experts_email"
                value={expertsEmail}
                onChange={(e) => setExpertsEmail(e.target.value)}
                className="mt-1 mb-4 block w-full border border-gray-300 rounded-md shadow-sm p-2 focus:outline-none focus:ring-2 focus:ring-blue-500 focus:border-blue-500"
                placeholder="Enter expert support email"
              />
              {/* Optional: Additional actions or info can go here */}
            </div>

            {/* Save Settings Button */}
            <div className="md:col-span-2 lg:col-span-3 flex justify-start">
              <button
                type="submit"
                className={`flex items-center justify-center ${
                  updateLoading ? 'bg-gray-300 cursor-not-allowed' : 'bg-orange-500 hover:bg-orange-600'
                } text-white px-6 py-3 rounded-lg text-sm font-semibold transition`}
                disabled={updateLoading}
              >
                <FaSave className="mr-2 w-4 h-4" />
                {updateLoading ? 'Saving...' : 'Save Settings'}
              </button>
            </div>
          </div>

          {/* Success Message */}
          {success && <p className="text-green-500 mt-4">{success}</p>}

          {/* Error Message */}
          {updateError && <p className="text-red-500 mt-4">{updateError}</p>}
        </form>
      )}
    </div>
  );
};

export default Settings;
